var parser = function (json) {
    switch (typeof json) {
        case 'string':
            return {
                type: 'String',
                value: json
            };
        case 'number':
            return {
                type: 'Number',
                value: json
            };
        case 'boolean':
            return {
                type: 'Boolean',
                value: json
            };
        case 'object':
            if (json === null) {
                return {
                    type: 'Null'
                };
            }
            else if (json instanceof Array) {
                return {
                    type: 'Array',
                    elements: json.map(function (json) { return parser(json); })
                };
            }
            else {
                return {
                    type: 'Object',
                    entries: Object.entries(json).map(function (_a) {
                        var key = _a[0], value = _a[1];
                        return ({
                            type: 'ObjectEntry',
                            key: key,
                            value: parser(value)
                        });
                    })
                };
            }
        default:
            throw new Error('Invalid type');
    }
};
export default parser;
